@@ -170,7 +170,7 @@ sub _relink_html {
 
 	my $is_xhtml = $this->{option}{type} eq 'xhtml' || 0;
 	my @intr = qw(form a);
-	$is_xhtml and push(@intr, qw(input br));
+	$is_xhtml and push(@intr, qw(input br option));
 	my $filter = $TL->newHtmlFilter(
 		interest => \@intr,
 	);
@@ -209,6 +209,10 @@ sub _relink_html {
 
 			# このリンクが内部リンクなら$saveの内容を追加
 			if(!$elem->attr('EXT')) {
+				if( $is_xhtml )
+				{
+					$context->add($context->newElement('div'));
+				}
 				foreach my $key ($this->{save}->getKeys) {
 					foreach my $value ($this->{save}->getValues($key)) {
 						my $e = $context->newElement('input');
@@ -230,6 +234,10 @@ sub _relink_html {
 						$context->add($e);
 					}
 				}
+				if( $is_xhtml )
+				{
+					$context->add($context->newElement('/div'));
+				}
 			} else {
 				$elem->attr(EXT => undef);
 			}
@@ -251,15 +259,24 @@ sub _relink_html {
 			}
 
 			$elem->attr(href => $newurl);
-		} elsif($elem_name_lc eq 'input' || $elem_name_lc eq 'br' ) {
-			if( $is_xhtml ) {
-				my $end = $elem->end || '';
-				if( $end =~ s/checked// && !$elem->attr('checked') )
-				{
-					$elem->attr('checked' => 'checked');
-				}
-				$elem->end('/');
+		} elsif($elem_name_lc =~ /^(input|br)$/ )
+		{
+			# ここに来るのは $is_xhtml の時だけ.
+			my $end = $elem->end || '';
+			if( $end =~ s/checked// && !$elem->attr('checked') )
+			{
+				$elem->attr('checked' => 'checked');
 			}
+			$elem->end('/');
+		} elsif($elem_name_lc eq 'option' )
+		{
+			# ここに来るのは $is_xhtml の時だけ.
+			my $end = $elem->end || '';
+			if( $end =~ s/selected// && !$elem->attr('selected') )
+			{
+				$elem->attr('selected' => 'selected');
+			}
+			$elem->end($end =~ /\S/ ? $end : '');
 		}
 	}
 
@@ -384,16 +401,33 @@ HTMLに対して以下の処理を行う。
 
 =over 4
 
-=item 漢字コード変換（デフォルトShift_JIS、Encode優先）
+=item *
 
-=item ヘッダの管理
+漢字コード変換（デフォルトShift_JIS、Encode優先）
 
-=item E<lt>form action=""E<gt> が空欄の場合、自分自身のCGI名を埋める
+=item *
 
-=item 特定フォームデータを指定された種別のリンクに付与する
+HTTPヘッダの管理
+
+=item *
+
+E<lt>form action=""E<gt> が空欄の場合、自分自身のCGI名を埋める
+
+=item *
+
+特定フォームデータを指定された種別のリンクに付与する
+
+=item *
+
+セッション利用時は、クッキーにセッション情報を保存する
 
 =back
 
+=head2 セッション
+
+セッションを利用している場合、http領域用のセッション情報は C<"SID + セッショングループ名">、
+https領域用のセッション情報は C<"SIDS + セッショングループ名"> という名称のクッキーに保存する。
+
 =head2 フィルタパラメータ
 
 =over 4
